@@ -132,6 +132,8 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
         self.in_get_workspace_diagnostics = Event(True)
 
+        self.refresh_task: Optional[asyncio.Task[Any]] = None
+
     async def initialized(self, sender: Any) -> None:
         self._ensure_diagnostics_thread_started()
 
@@ -216,19 +218,16 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
         ...
 
     async def ensure_workspace_loaded(self) -> None:
-        if not self._workspace_loaded:
-            async with self._workspace_load_lock:
-                if not self._workspace_loaded:
-                    if self.workspace_loaded_event.is_set():
-                        return
-
-                    try:
-                        await self.load_workspace_documents(self)
-                    finally:
-                        self._workspace_loaded = True
-                        self.workspace_loaded_event.set()
-                        await self.on_workspace_loaded(self)
-                        await self.force_refresh_all()
+        async with self._workspace_load_lock:
+            if not self._workspace_loaded and not self.workspace_loaded_event.is_set():
+                self._logger.debug("load workspace documents")
+                try:
+                    await self.load_workspace_documents(self)
+                finally:
+                    self._workspace_loaded = True
+                    self.workspace_loaded_event.set()
+                    await self.on_workspace_loaded(self)
+                    await self.force_refresh_all()
 
     async def force_refresh_all(self, refresh: bool = True) -> None:
         for doc in self.parent.documents.documents:
@@ -293,9 +292,12 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
                 documents = [
                     doc
                     for doc in self.parent.documents.documents
-                    if (data := self.get_diagnostics_data(doc)).force
-                    or doc.version != data.version
-                    or data.task is None
+                    if not doc.opened_in_editor
+                    and (
+                        (data := self.get_diagnostics_data(doc)).force
+                        or doc.version != data.version
+                        or data.task is None
+                    )
                 ]
 
                 if len(documents) == 0:
@@ -360,7 +362,17 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
             if task is not None and not task.done():
                 self._logger.debug(lambda: f"try to cancel diagnostics for {document}")
-                task.get_loop().call_soon_threadsafe(task.cancel)
+
+                async def cancel(t: asyncio.Task[Any]) -> None:
+                    t.cancel()
+                    try:
+                        await t
+                    except asyncio.CancelledError:
+                        pass
+
+                asyncio.run_coroutine_threadsafe(cancel(task), loop=task.get_loop()).result(5)
+
+                # task.get_loop().call_soon_threadsafe(task.cancel)
 
             data.version = document.version
             data.task = create_sub_task(
@@ -480,7 +492,19 @@ class DiagnosticsProtocolPart(LanguageServerProtocolPart, HasExtendCapabilities)
 
         return DiagnosticsMode.OPENFILESONLY
 
-    async def refresh(self) -> None:
+    async def __do_refresh(self, now: bool = False) -> None:
+        if not now:
+            await asyncio.sleep(1)
+
+        await self.__refresh()
+
+    async def refresh(self, now: bool = False) -> None:
+        if self.refresh_task is not None and not self.refresh_task.done():
+            self.refresh_task.get_loop().call_soon_threadsafe(self.refresh_task.cancel)
+
+        self.refresh_task = create_sub_task(self.__do_refresh(now), loop=self.diagnostics_loop)
+
+    async def __refresh(self) -> None:
         if (
             self.parent.client_capabilities
             and self.parent.client_capabilities.workspace
