@@ -3,8 +3,6 @@ from __future__ import annotations
 import ast
 import asyncio
 import os
-import sys
-import threading
 import weakref
 from abc import ABC, abstractmethod
 from collections import OrderedDict
@@ -26,7 +24,7 @@ from typing import (
 )
 
 from ....utils.async_cache import AsyncSimpleLRUCache
-from ....utils.async_tools import Lock, async_tasking_event, create_sub_task
+from ....utils.async_tools import Lock, async_tasking_event, create_sub_task, threaded
 from ....utils.logging import LoggingDescriptor
 from ....utils.path import path_is_relative_to
 from ....utils.uri import Uri
@@ -262,14 +260,13 @@ class _LibrariesEntry(_ImportEntry):
             return self._lib_doc is not None
 
     async def get_libdoc(self) -> LibraryDoc:
-        if self._lib_doc is None:
-            async with self._lock:
-                if self._lib_doc is None:
-                    await self._update()
+        async with self._lock:
+            if self._lib_doc is None:
+                await self._update()
 
-                assert self._lib_doc is not None
+            assert self._lib_doc is not None
 
-        return self._lib_doc
+            return self._lib_doc
 
 
 @dataclass()
@@ -344,9 +341,8 @@ class _ResourcesEntry(_ImportEntry):
             return self._document is not None
 
     async def get_document(self) -> TextDocument:
-        if self._document is None:
-            async with self._lock:
-                await self._get_document()
+        async with self._lock:
+            await self._get_document()
 
         assert self._document is not None
 
@@ -368,11 +364,11 @@ class _ResourcesEntry(_ImportEntry):
         return await self.parent.parent_protocol.documents_cache.get_resource_namespace(await self._get_document())
 
     async def get_libdoc(self) -> LibraryDoc:
-        if self._lib_doc is None:
-            async with self._lock:
-                if self._lib_doc is None:
-                    self._lib_doc = await (await self._get_namespace()).get_library_doc()
-        return self._lib_doc
+        async with self._lock:
+            if self._lib_doc is None:
+                self._lib_doc = await (await self._get_namespace()).get_library_doc()
+
+            return self._lib_doc
 
 
 @dataclass()
@@ -446,14 +442,13 @@ class _VariablesEntry(_ImportEntry):
             return self._lib_doc is not None
 
     async def get_libdoc(self) -> VariablesDoc:
-        if self._lib_doc is None:
-            async with self._lock:
-                if self._lib_doc is None:
-                    await self._update()
+        async with self._lock:
+            if self._lib_doc is None:
+                await self._update()
 
-                assert self._lib_doc is not None
+            assert self._lib_doc is not None
 
-        return self._lib_doc
+            return self._lib_doc
 
 
 class ImportsManager:
@@ -476,10 +471,8 @@ class ImportsManager:
         self._command_line_variables: Optional[List[VariableDefinition]] = None
         self._command_line_variables_lock = Lock()
 
-        self._python_path: Optional[List[str]] = None
-        self._python_path_lock = threading.RLock()
-        self._environment: Optional[Mapping[str, str]] = None
-        self._environment_lock = threading.RLock()
+        self._environment = dict(os.environ)
+        self._environment.update(self.config.env)
 
         self._library_files_cache = AsyncSimpleLRUCache()
         self._resource_files_cache = AsyncSimpleLRUCache()
@@ -487,31 +480,7 @@ class ImportsManager:
 
     @property
     def environment(self) -> Mapping[str, str]:
-        with self._environment_lock:
-            if self._environment is None:
-                self._environment = dict(os.environ)
-
-                self._environment.update(self.config.env)
-
-            return self._environment
-
-    @property
-    def python_path(self) -> List[str]:
-        with self._python_path_lock:
-            if self._python_path is None:
-                self._python_path = sys.path
-
-                file = Path(__file__).resolve()
-                top = file.parents[3]
-                for p in filter(lambda v: path_is_relative_to(v, top), sys.path.copy()):
-                    self._python_path.remove(p)
-
-            for p in self.config.python_path:
-                absolute_path = str(Path(p).absolute())
-                if absolute_path not in self._python_path:
-                    self._python_path.insert(0, absolute_path)
-
-            return self._python_path
+        return self._environment
 
     @_logger.call
     async def get_command_line_variables(self) -> List[VariableDefinition]:
@@ -559,10 +528,12 @@ class ImportsManager:
     async def imports_changed(sender, uri: DocumentUri) -> None:  # NOSONAR
         ...
 
+    @threaded()
     async def _do_imports_changed(self, sender: Any, uri: DocumentUri) -> None:  # NOSONAR
         await self.imports_changed(self, uri)
 
     @language_id("robotframework")
+    @threaded()
     async def resource_document_changed(self, sender: Any, document: TextDocument) -> None:
         resource_changed: List[LibraryDoc] = []
 
@@ -721,8 +692,6 @@ class ImportsManager:
                 name,
                 str(self.folder.to_path()),
                 base_dir,
-                self.config.python_path if self.config is not None else None,
-                self.config.env if self.config is not None else None,
                 self.config.variables if self.config is not None else None,
                 variables,
             )
@@ -733,7 +702,7 @@ class ImportsManager:
             result = name
 
         if is_library_by_path(result):
-            result = find_file_ex(result, base_dir, self.python_path, "Library")
+            result = find_file_ex(result, base_dir, "Library")
 
         return result
 
@@ -753,14 +722,12 @@ class ImportsManager:
                 name,
                 str(self.folder.to_path()),
                 base_dir,
-                self.config.python_path if self.config is not None else None,
-                self.config.env if self.config is not None else None,
                 self.config.variables if self.config is not None else None,
                 variables,
                 file_type,
             )
 
-        return str(find_file_ex(name, base_dir, self.python_path, file_type))
+        return str(find_file_ex(name, base_dir, file_type))
 
     async def find_variables(self, name: str, base_dir: str, variables: Optional[Dict[str, Any]] = None) -> str:
         return await self._variables_files_cache.get(self.__find_variables, name, base_dir, variables)
@@ -774,8 +741,6 @@ class ImportsManager:
                 name,
                 str(self.folder.to_path()),
                 base_dir,
-                self.config.python_path if self.config is not None else None,
-                self.config.env if self.config is not None else None,
                 self.config.variables if self.config is not None else None,
                 variables,
             )
@@ -783,11 +748,11 @@ class ImportsManager:
         if get_robot_version() >= (5, 0):
 
             if is_variables_by_path(name):
-                return str(find_file_ex(name, base_dir, self.python_path, "Library"))
+                return str(find_file_ex(name, base_dir, "Library"))
 
             return name
 
-        return str(find_file_ex(name, base_dir, self.python_path, "Library"))
+        return str(find_file_ex(name, base_dir, "Library"))
 
     @_logger.call
     async def get_libdoc_for_library_import(
@@ -816,8 +781,6 @@ class ImportsManager:
                         args,
                         str(self.folder.to_path()),
                         base_dir,
-                        self.config.python_path if self.config is not None else None,
-                        self.config.env if self.config is not None else None,
                         self.config.variables if self.config is not None else None,
                         variables,
                     ),
@@ -833,12 +796,11 @@ class ImportsManager:
 
         entry_key = _LibrariesEntryKey(source, args)
 
-        if entry_key not in self._libaries:
-            async with self._libaries_lock:
-                if entry_key not in self._libaries:
-                    self._libaries[entry_key] = _LibrariesEntry(
-                        name, args, self, _get_libdoc, ignore_reference=sentinel is None
-                    )
+        async with self._libaries_lock:
+            if entry_key not in self._libaries:
+                self._libaries[entry_key] = _LibrariesEntry(
+                    name, args, self, _get_libdoc, ignore_reference=sentinel is None
+                )
 
         entry = self._libaries[entry_key]
 
@@ -1000,8 +962,6 @@ class ImportsManager:
                         args,
                         str(self.folder.to_path()),
                         base_dir,
-                        self.config.python_path if self.config is not None else None,
-                        self.config.env if self.config is not None else None,
                         self.config.variables if self.config is not None else None,
                         variables,
                     ),
@@ -1016,10 +976,9 @@ class ImportsManager:
 
         entry_key = _VariablesEntryKey(source, args)
 
-        if entry_key not in self._variables:
-            async with self._variables_lock:
-                if entry_key not in self._variables:
-                    self._variables[entry_key] = _VariablesEntry(name, args, self, _get_libdoc)
+        async with self._variables_lock:
+            if entry_key not in self._variables:
+                self._variables[entry_key] = _VariablesEntry(name, args, self, _get_libdoc)
 
         entry = self._variables[entry_key]
 
@@ -1050,11 +1009,10 @@ class ImportsManager:
 
         entry_key = _ResourcesEntryKey(source)
 
-        if entry_key not in self._resources:
-            async with self._resources_lock:
+        async with self._resources_lock:
 
-                if entry_key not in self._resources:
-                    self._resources[entry_key] = _ResourcesEntry(name, self, _get_document)
+            if entry_key not in self._resources:
+                self._resources[entry_key] = _ResourcesEntry(name, self, _get_document)
 
         entry = self._resources[entry_key]
 
@@ -1100,8 +1058,6 @@ class ImportsManager:
             name,
             str(self.folder.to_path()),
             base_dir,
-            self.config.python_path if self.config is not None else None,
-            self.config.env if self.config is not None else None,
             self.config.variables if self.config is not None else None,
             variables,
         )
@@ -1113,8 +1069,6 @@ class ImportsManager:
             name,
             str(self.folder.to_path()),
             base_dir,
-            self.config.python_path if self.config is not None else None,
-            self.config.env if self.config is not None else None,
             self.config.variables if self.config is not None else None,
             variables,
         )
@@ -1127,22 +1081,15 @@ class ImportsManager:
             name,
             str(self.folder.to_path()),
             base_dir,
-            self.config.python_path if self.config is not None else None,
-            self.config.env if self.config is not None else None,
             self.config.variables if self.config is not None else None,
             variables,
         )
 
-    async def resolve_variable(
-        self, name: str, base_dir: str = ".", variables: Optional[Dict[str, Any]] = None, ignore_errors: bool = True
-    ) -> Any:
+    def resolve_variable(self, name: str, base_dir: str = ".", variables: Optional[Dict[str, Any]] = None) -> Any:
         return resolve_variable(
             name,
             str(self.folder.to_path()),
             base_dir,
-            self.config.python_path if self.config is not None else None,
-            self.config.env if self.config is not None else None,
             self.config.variables if self.config is not None else None,
             variables,
-            ignore_errors,
         )
